has_question_word: Question Words

Description Usage Arguments Examples

View source: R/clickbait_functions.R

Description

This function takes in any string and returns a boolean indicating whether or not one of the phrases within the dataframe question is present. This function is intended for use on any of the clickbait MEA datasets.

Usage

1

Arguments

text

string/ headline

Examples

1
2
headlines_question <- headlines %>%
   mutate(has_question_word = has_question_word(text = title))

phebepalmer/textclassificationexamples documentation built on Aug. 22, 2020, 12:11 a.m.