Description Usage Arguments Examples
View source: R/spam_functions.R
This function takes in any string and returns a boolean indicating whether or not religious words are present. This function is intended for use on any of the email MEA datasets.
1 |
text |
string/ email subject line |
1 2 | emails_religious <- emails %>%
mutate(has_religious = has_religious(text = subjectline))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.